@@ -12,7 +12,7 @@ use base qw(Net::DNS::Resolver::Base DynaLoader), OS_CONF;
 our $VERSION;
 
 BEGIN {
-	$VERSION = '1.27_01';
+	$VERSION = '1.27_02';
 	eval { __PACKAGE__->bootstrap($VERSION) };
 }
 
@@ -128,8 +128,8 @@ sub new {
 	nameserver => '2001:4860:4860::8888@853#dns.google',
 	nameserver => '8.8.8.8@853#dns.google',
 	nameserver => '9.9.9.9@853#dns.quad9.net',
-	option     => [qw(tls-cert-bundle /etc/ssl/cert.pem)],
-	set_tls    => 1
+	option	   => [qw(tls-cert-bundle /etc/ssl/cert.pem)],
+	set_tls	   => 1
 	);
 
     $resolver->nameservers( '::1', '127.0.0.1', ... );
@@ -512,8 +512,9 @@ sub _decode_result {
 sub _config {
 	my ( $self, $name, @arg ) = @_;
 	my $entry = ( scalar(@arg) == 1 ) ? $arg[0] : [@arg];
-	$self->{test_ctx} = Net::DNS::Resolver::Unbound::Context->new() unless $self->{update};
-	$self->{test_ctx}->$name(@arg) if @arg;			# error check only
+	my $ctx	  = $self->{test_ctx};
+	$ctx = $self->{test_ctx} = Net::DNS::Resolver::Unbound::Context->new() unless $ctx;
+	$ctx->$name(@arg) if @arg;				# error check only
 	my $state = $self->{update}->{$name};
 	if ( defined $state ) {					# second and subsequent entries
 		$state = $self->{update}->{$name} = [$state] unless ref $state;
@@ -528,9 +529,10 @@ sub _config {
 sub _option {
 	my ( $self, $name, @arg ) = @_;
 	my ($entry) = @arg;
-	my $opt = "${name}:";
-	$self->{test_ctx} = Net::DNS::Resolver::Unbound::Context->new() unless $self->{update};
-	$self->{test_ctx}->set_option( $opt, @arg ) if defined $entry;	  # error check only
+	my $opt	    = "${name}:";
+	my $ctx	    = $self->{test_ctx};
+	$ctx = $self->{test_ctx} = Net::DNS::Resolver::Unbound::Context->new() unless $ctx;
+	$ctx->set_option( $opt, @arg ) if defined $entry;	# error check only
 	my $updopt = $self->{update}->{set_option};
 	my %option = map {$_} @$updopt;
 
@@ -570,6 +572,8 @@ sub _finalise_config {
 
 	my $update = delete $self->{update};
 	return unless $update;
+
+	delete $self->{test_ctx};
 	my $ctx = $self->{ub_ctx} = Net::DNS::Resolver::Unbound::Context->new();
 
 	my $config = $self->{config};
